==> pdf-model-arlington-1.25.15-sources.jar: org/verapdf/model/alayer/ASigFieldLock.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface ASigFieldLock extends AObject {
	


	/**
	*/
	public Boolean getcontainsAction();

	/**
	*/
	public Boolean getActionHasTypeName();

	/**
	*/
	public String getActionNameValue();

	/**
	*/
	public Boolean getcontainsFields();

	/**
	*/
	public Boolean getFieldsHasTypeArray();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public Boolean getPHasTypeNumber();

	/**
	*/
	public Double getPNumberValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean gethasExtensionADBE_Extn3();
}

==> pdf-model-arlington-1.25.30-sources.jar: org/verapdf/model/alayer/ASigFieldLock.java <==
/**
 * This file is part of veraPDF Validation Model API, a module of the veraPDF project.
 * Copyright (c) 2015, veraPDF Consortium <info@verapdf.org>
 * All rights reserved.
 *
 * veraPDF Validation Model API is free software: you can redistribute it and/or modify
 * it under the terms of either:
 *
 * The GNU General public license GPLv3+.
 * You should have received a copy of the GNU General Public License
 * along with veraPDF Validation Model API as the LICENSE.GPL file in the root of the source
 * tree.  If not, see http://www.gnu.org/licenses/ or
 * https://www.gnu.org/licenses/gpl-3.0.en.html.
 *
 * The Mozilla Public License MPLv2+.
 * You should have received a copy of the Mozilla Public License along with
 * veraPDF Validation Model API as the LICENSE.MPL file in the root of the source tree.
 * If a copy of the MPL was not distributed with this file, you can obtain one at
 * http://mozilla.org/MPL/2.0/.
 */
package org.verapdf.model.alayer;
		
import org.verapdf.model.baselayer.Object;

		
/**
*/
public interface ASigFieldLock extends AObject {
	


	/**
	*/
	public Boolean getcontainsAction();

	/**
	*/
	public String getActionType();

	/**
	*/
	public Boolean getActionHasTypeName();

	/**
	*/
	public String getActionNameValue();

	/**
	*/
	public Boolean getcontainsFields();

	/**
	*/
	public String getFieldsType();

	/**
	*/
	public Boolean getFieldsHasTypeArray();

	/**
	*/
	public Boolean getcontainsP();

	/**
	*/
	public String getPType();

	/**
	*/
	public Boolean getPHasTypeNumber();

	/**
	*/
	public Double getPNumberValue();

	/**
	*/
	public Boolean getcontainsType();

	/**
	*/
	public String getTypeType();

	/**
	*/
	public Boolean getTypeHasTypeName();

	/**
	*/
	public String getTypeNameValue();

	/**
	*/
	public Boolean gethasExtensionADBE_Extn3();
}
